package com.muyu.system.domain.model;

import com.muyu.common.core.web.model.QueryModel;
import com.muyu.system.domain.req.SysDeptListReq;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 参数配置 分页 模型
 * @author dongzeliang
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = false)
public class SysDeptPageQueryModel extends QueryModel<SysDeptPageQueryModel> {

    /**
     * 部门ID
     */
    private Long deptId;

    /**
     * 部门名称
     */
    private String deptName;

    /**
     * 部门状态:0正常,1停用
     */
    private String status;


    /**
     * 根据部门请求对象构建查询对象
     * @param sysDeptListReq 部门列表请求对象
     * @return 部门请求构建查询对象
     */
    public static SysDeptPageQueryModel reqBuild(SysDeptListReq sysDeptListReq) {
        return SysDeptPageQueryModel.builder()
                .deptName(sysDeptListReq.getDeptName())
                .status(sysDeptListReq.getStatus())
                .build();
    }

    /**
     * 根据部门ID构建查询对象
     * @param deptId 部门ID
     * @return 部门查询对象
     */
    public static SysDeptPageQueryModel ofToDeptId(Long deptId) {
        return SysDeptPageQueryModel.builder()
                .deptId(deptId)
                .build();
    }

    /**
     * 构建一个空对象
     * @return 查询模型空对象
     */
    public static SysDeptPageQueryModel ofNull() {
        return new SysDeptPageQueryModel();
    }
}
