package com.muyu.system.domain.model;

import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.core.xss.Xss;
import com.muyu.system.domain.req.SysNoticeUpdReq;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.function.Supplier;

/**
 * 通知公告修改模型
 *
 * @author 夜は眠れるかい?
 * @Date 2025/2/24 15:58
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class SysNoticeUpdModel extends BaseEntity {

    /**
     * 公告标题
     */
    @Xss(message = "公告标题不能包含脚本字符")
    @NotBlank(message = "公告标题不能为空")
    @Size(min = 0, max = 50, message = "公告标题不能超过50个字符")
    private String noticeTitle;

    /**
     * 公告类型（1通知 2公告）
     */
    private String noticeType;

    /**
     * 公告内容
     */
    private String noticeContent;

    /**
     * 公告状态（0正常 1关闭）
     */
    private String status;


    /**
     * 将通知公告修改请求对象构建成通知公告修改模型
     *
     * @param sysNoticeUpdReq 通知公告修改请求对象
     * @param updateBy 通知公告修改模型
     * @return 通知公告修改模型
     */
    public static SysNoticeUpdModel updReqBuildToModel(SysNoticeUpdReq sysNoticeUpdReq, Supplier<String> updateBy){
        return SysNoticeUpdModel.builder()
                .noticeTitle(sysNoticeUpdReq.getNoticeTitle())
                .noticeType(sysNoticeUpdReq.getNoticeType())
                .noticeContent(sysNoticeUpdReq.getNoticeContent())
                .status(sysNoticeUpdReq.getStatus())
                .remark(sysNoticeUpdReq.getRemark())
                .updateBy(updateBy.get())
                .updateTime(new Date())
                .build();
    }
}
