package com.muyu.system.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.system.domain.req.SysOperLogAddReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

/**
 * 操作日志记录添加模型
 *
 * @author 夜は眠れるかい?
 * @Date 2025/2/23 22:21
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SysOperLogAddModel {

    /**
     * 日志主键
     */
    private Long operId;

    /**
     * 操作模块
     */
    private String title;

    /**
     * 业务类型（0其它 1新增 2修改 3删除）
     */
    private Integer businessType;

    /**
     * 请求方法
     */
    private String method;

    /**
     * 请求方式
     */
    private String requestMethod;

    /**
     * 操作类别（0其它 1后台用户 2手机端用户）
     */
    private Integer operatorType;

    /**
     * 操作人员
     */
    private String operName;

    /**
     * 部门名称
     */
    private String deptName;

    /**
     * 请求url
     */
    private String operUrl;

    /**
     * 操作地址
     */
    private String operIp;

    /**
     * 请求参数
     */
    private String operParam;

    /**
     * 返回参数
     */
    private String jsonResult;

    /**
     * 操作状态（0正常 1异常）
     */
    private Integer status;

    /**
     * 错误消息
     */
    private String errorMsg;

    /**
     * 操作时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date operTime;

    /**
     * 消耗时间
     */
    private Long costTime;


    /**
     * 将操作日志记录添加请求对象构建成操作日志记录添加模型
     *
     * @param sysOperLogAddReq 操作日志记录添加请求对象
     * @return 操作日志记录添加模型
     */
    public static SysOperLogAddModel addReqBuildToModel(SysOperLogAddReq sysOperLogAddReq){
        return SysOperLogAddModel.builder()
                .operId(sysOperLogAddReq.getOperId())
                .title(sysOperLogAddReq.getTitle())
                .businessType(sysOperLogAddReq.getBusinessType())
                .method(sysOperLogAddReq.getMethod())
                .requestMethod(sysOperLogAddReq.getRequestMethod())
                .operatorType(sysOperLogAddReq.getOperatorType())
                .operName(sysOperLogAddReq.getOperName())
                .deptName(sysOperLogAddReq.getDeptName())
                .operUrl(sysOperLogAddReq.getOperUrl())
                .operIp(sysOperLogAddReq.getOperIp())
                .operParam(sysOperLogAddReq.getOperParam())
                .jsonResult(sysOperLogAddReq.getJsonResult())
                .status(sysOperLogAddReq.getStatus())
                .errorMsg(sysOperLogAddReq.getErrorMsg())
                .operTime(new Date())
                .costTime(sysOperLogAddReq.getCostTime())
                .build();
    }
}
