package com.muyu.system.domain.req;

import com.muyu.system.domain.SysMenu;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.List;

/**
 * 菜单添加请求
 * @description: 菜单添加请求
 * @author yangchoashun
 * @date 2025/2/23 17:24
 * @version 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SysMenuAddReq {
    private Long menuId;

    /**
     * 菜单名称
     */
    @NotBlank(message = "菜单名称不能为空")
    private String menuName;

    /**
     * 父菜单名称
     */
    private String parentName;

    /**
     * 父菜单ID
     */

    private Long parentId;

    /**
     * 显示顺序
     */
    @NotNull(message = "显示顺序不能为空")
    private Integer orderNum;

    /**
     * 路由地址
     */
    @NotBlank(message = "路由地址不能为空")
    private String path;

    /**
     * 组件路径
     */
   @NotBlank(message = "组件路径不能为空")
    private String component;

    /**
     * 路由参数
     */
    private String query;

    /**
     * 是否为外链（0是 1否）
     */
    @NotBlank(message = "是否为外链不能为空")
    private String isFrame;

    /**
     * 是否缓存（0缓存 1不缓存）
     */
    @NotBlank(message = "是否缓存不能为空")
    private String isCache;

    /**
     * 类型（M目录 C菜单 F按钮）
     */
    @NotBlank(message = "类型不能为空")
    private String menuType;

    /**
     * 显示状态（0显示 1隐藏）
     */
    @NotBlank(message = "显示状态不能为空")
    private String visible;

    /**
     * 菜单状态（0正常 1停用）
     */
    @NotBlank(message = "菜单状态不能为空")
    private String status;

    /**
     * 权限字符串
     */
    private String perms;

    /**
     * 菜单图标
     */
    @NotBlank(message = "菜单图标不能为空")
    private String icon;

    /**
     * 子菜单
     */
    private List<SysMenu> children = new ArrayList<>();

}
