package com.muyu.system.domain.resp;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.system.domain.SysDictData;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 数据字典数据集合返回结果
 * @author SunLY
 * @description: 数据字典数据集合返回结果
 * @date 2025/2/23 21:24
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class SysDictDataListResp extends BaseEntity {
    /**
     * 字典编码
     */
    @Excel(name = "字典编码", cellType = Excel.ColumnType.NUMERIC)
    private Long dictCode;

    /**
     * 字典排序
     */
    @Excel(name = "字典排序", cellType = Excel.ColumnType.NUMERIC)
    private Long dictSort;

    /**
     * 字典标签
     */
    @Excel(name = "字典标签")
    private String dictLabel;

    /**
     * 字典键值
     */
    @Excel(name = "字典键值")
    private String dictValue;

    /**
     * 字典类型
     */
    @Excel(name = "字典类型")
    private String dictType;

    /**
     * 样式属性（其他样式扩展）
     */
    private String cssClass;

    /**
     * 表格字典样式
     */
    private String listClass;

    /**
     * 是否默认（Y是 N否）
     */
    @Excel(name = "是否默认", readConverterExp = "Y=是,N=否")
    private String isDefault;

    /**
     * 状态（0正常 1停用）
     */
    @Excel(name = "状态", readConverterExp = "0=正常,1=停用")
    private String status;

    public static SysDictDataListResp buildResp(SysDictData sysDictData){
        return SysDictDataListResp.builder()
                .dictCode(sysDictData.getDictCode())
                .dictSort(sysDictData.getDictSort())
                .dictLabel(sysDictData.getDictLabel())
                .dictValue(sysDictData.getDictValue())
                .dictType(sysDictData.getDictType())
                .cssClass(sysDictData.getCssClass())
                .listClass(sysDictData.getListClass())
                .isDefault(sysDictData.getIsDefault())
                .status(sysDictData.getStatus())
                .build();
    }
}
