package com.muyu.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.common.system.domain.SysDept;
import com.muyu.system.domain.model.CheckDeptNameUniqueModel;
import com.muyu.system.domain.model.SysDeptPageQueryModel;
import com.muyu.system.domain.vo.TreeSelect;

import java.util.List;

/**
 * 部门管理 服务层
 *
 * @author muyu
 */
public interface SysDeptService extends IService<SysDept> {
    /**
     * 查询部门管理数据
     *
     * @param deptPageQueryModel 部门信息
     *
     * @return 部门信息集合
     */
    public List<SysDept> selectDeptList (SysDeptPageQueryModel deptPageQueryModel);

    /**
     * 查询部门树结构信息
     *
     * @return 部门树信息集合
     */
    public List<TreeSelect> selectDeptTreeList ();

    /**
     * 构建前端所需要树结构
     *
     * @param depts 部门列表
     *
     * @return 树结构列表
     */
    public List<SysDept> buildDeptTree (List<SysDept> depts);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param depts 部门列表
     *
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildDeptTreeSelect (List<SysDept> depts);

    /**
     * 根据角色ID查询部门树信息
     *
     * @param roleId 角色ID
     *
     * @return 选中部门列表
     */
    public List<Long> selectDeptListByRoleId (Long roleId);

    /**
     * 根据部门ID查询信息
     *
     * @param deptId 部门ID
     *
     * @return 部门信息
     */
    public SysDept selectDeptById (Long deptId);

    /**
     * 根据ID查询所有子部门（正常状态）
     *
     * @param deptId 部门ID
     *
     * @return 子部门数
     */
    public int selectNormalChildrenDeptById (Long deptId);

    /**
     * 是否存在部门子节点
     *
     * @param deptId 部门ID
     *
     * @return 结果
     */
    public boolean hasChildByDeptId (Long deptId);

    /**
     * 查询部门是否存在用户
     *
     * @param deptId 部门ID
     *
     * @return 结果 true 存在 false 不存在
     */
    public boolean checkDeptExistUser (Long deptId);

    /**
     * 校验部门名称是否唯一
     *
     * @param checkDeptNameUniqueModel 部门信息
     * @return 结果
     */
    public boolean checkDeptNameUnique (CheckDeptNameUniqueModel checkDeptNameUniqueModel);

    /**
     * 校验部门是否有数据权限
     *
     * @param deptId 部门id
     */
    public void checkDeptDataScope (Long deptId);

    /**
     * 新增保存部门信息
     *
     * @param dept 部门信息
     *
     * @return 结果
     */
    public void insertDept (SysDept dept);

    /**
     * 修改保存部门信息
     *
     * @param dept 部门信息
     *
     * @return 结果
     */
    public void updateDept (SysDept dept);

    /**
     * 删除部门管理信息
     *
     * @param deptId 部门ID
     *
     * @return 结果
     */
    public void deleteDeptById (Long deptId);

    /**
     * 查询部门信息
     * @param sysDeptPageQueryModel 部门查询模型
     * @return 分页返回结果
     */
    List<SysDept> queryList(SysDeptPageQueryModel sysDeptPageQueryModel);

    /**
     * 根据ID查询所有子部门
     *
     * @param deptId 部门ID
     *
     * @return 部门列表
     */
    public List<SysDept> selectChildrenDeptById (Long deptId);
}
